@@ -100,11 +100,14 @@ class SClient(Wss):
                 return Json((await req.json()))
 
     async def check_device(self, deviceId: str):
-        head = self.headers
-        head["NDCDEVICEID"] = deviceId
-        async with self.session.post(api(f"/g/s/device"), headers=head) as req:
+        data = json.dumps({
+            "deviceID": deviceId,
+            "timestamp": int(timestamp() * 1000),
+            "clientType": 100
+        })
+        async with self.session.post(api(f"/g/s/device"), headers=headers.Headers(data=data).headers, data=data) as req:
             if (await req.json())["api:statuscode"] != 0: return CheckExceptions(await req.json())
-            return Json((await req.json()))
+            else: return f"api:message {(await req.json())['api:message']}\napi:statuscode {(await req.json())['api:statuscode']}\nThe device is fine"
 
     async def upload_image(self, image: BinaryIO):
         data = image.read()
@@ -327,23 +330,29 @@ class SClient(Wss):
             if req.status != 200: return CheckExceptions(await req.json())
             return (await req.json())["blockedUidList"]
 
-    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
+    async def get_wall_comments(self, userId: str, sorting: str = 'newest', start: int = 0, size: int = 25):
         sorting = sorting.lower()
-
-        if sorting == "newest":
-            sorting = "newest"
-        elif sorting == "oldest":
-            sorting = "oldest"
-        elif sorting == "top":
-            sorting = "vote"
-        else:
-            raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
 
         async with self.session.get(api(f"/g/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}"),
                            headers=self.headers ) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return CommentList((await req.json())["commentList"]).CommentList
 
+    async def get_blog_comments(self, wikiId:str = None, blogId:str = None, quizId: str = None, sorting: str = 'newest',size: int = 25, start: int = 0):
+        sorting = sorting.lower()
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
+
+        if quizId: blogId = quizId
+        if blogId: url = api(f"/g/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}")
+        elif wikiId: url = api(f"/g/s/item/{wikiId}/comment?sort={sorting}&start={start}&size={size}")
+
+        async with self.session.get(url, headers=self.headers, proxies=self.proxies) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            else: return CommentList((await req.json())["commentList"]).CommentList
+
     async def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
                      fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None,
                      snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
@@ -739,11 +748,19 @@ class SClient(Wss):
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
-    async def watch_ad(self, uid: str = None):
-        data = headers.AdHeaders(uid if uid else self.uid).data
-        async with self.session.post(tapjoy, json=data, headers=headers.AdHeaders().headers) as req:
-            print(req.status)
-            if req.status != 204:
-                return CheckExceptions(req.status)
-            else:
-                return Json(await req.text)
+    async def remove_host(self, chatId: str, userId: str):
+        async with self.session.delete(api(f"/g/s/chat/thread/{chatId}/co-host/{userId}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
+
+    async def edit_comment(self, commentId: str, comment: str, userId: str):
+        data = {"content": comment, "timestamp": int(timestamp() * 1000)}
+        data = json.dumps(data)
+        async with self.session.post(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), data=data, headers=headers.Headers(data=data).headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Comment(await req.json()).Comments
+
+    async def get_comment_info(self, commentId: str, userId: str):
+        async with self.session.get(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Comment(await req.json()).Comments
