@@ -470,18 +470,28 @@ class SLocal:
             if req.status != 200: return CheckExceptions(await req.json())
             return Comment(await req.json()).Comments
 
-    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
+    async def get_wall_comments(self, userId: str, sorting: str = 'newest', start: int = 0, size: int = 25):
         sorting = sorting.lower()
-
-        if sorting == "newest": sorting = "newest"
-        elif sorting == "oldest": sorting = "oldest"
-        elif sorting == "top": sorting = "vote"
-        else: raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf) //// a7a wtf
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
 
         async with self.session.get(api(f"/x{self.comId}/s/user-profile/{userId}/comment?sort={sorting}&start={start}&size={size}"), headers=self.headers) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return CommentList((await req.json())["commentList"]).CommentList
 
+    async def get_blog_comments(self, wikiId: str = None, blogId: str = None, quizId: str = None, sorting: str = 'newest', size: int = 25, start: int = 0):
+        sorting = sorting.lower()
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
+
+        if quizId: blogId = quizId
+        if blogId: url = api(f"/x{self.comId}/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}")
+        elif wikiId: url = api(f"/x{self.comId}/s/item/{wikiId}/comment?sort={sorting}&start={start}&size={size}")
+
+        async with self.session.get(url, headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            else: return CommentList((await req.json())["commentList"]).CommentList
+
     async def vote_comment(self, blogId: str, commentId: str, value: bool = True):
         if value: value = 1
         else: value = -1
@@ -564,8 +574,7 @@ class SLocal:
                 else: return Json(await req.json())
 
     async def invite_by_host(self, chatId: str, userId: [str, list]):
-        data = json.dumps({"uidList": userId, "timestamp": int(timestamp() * 1000)})
-        async with self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/avchat-members"), headers=headers.Headers(data=data).headers, data=data) as req:
+        async with self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/member/{userId}/invite-av-chat"), headers=headers.Headers(data=data).headers) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return Json(await req.json())
 
@@ -620,7 +629,9 @@ class SLocal:
         elif chatId: url = api(f"/x{self.comId}/s/chat/thread/{chatId}/admin")
         else: raise TypeError("Please put a wiki or user or chat or blog Id")
 
-        data = {"adminOpNote": {"content": note}, "adminOpName": opN, "adminOpValue": opV, "timestamp": int(timestamp() * 1000)}
+        data = {"adminOpName": opN, "adminOpValue": opV, "timestamp": int(timestamp() * 1000)}
+        if note: data["adminOpNote"] = {"content": note}
+        data = json.dumps(data)
         async with self.session.post(url, headers=headers.Headers(data=data).headers, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json(await req.json())
@@ -637,12 +648,12 @@ class SLocal:
         else: raise TypeError("Please put a wiki or user or chat or blog Id")
 
         data = {
-            "adminOpNote": {"content": note},
             "adminOpName": opN,
             "adminOpValue": opV,
             "timestamp": int(timestamp() * 1000)
         }
-
+        if note: data["adminOpNote"] = {"content": note}
+        data = json.dumps(data)
         async with self.session.post(url, headers=headers.Headers(data=data).headers, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json(await req.json())
@@ -845,3 +856,52 @@ class SLocal:
         async with self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/transfer-organizer/{requestId}/accept"), headers=headers.Headers(data=data).headers, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return Json(await req.json())
+
+    async def remove_host(self, chatId: str, userId: str):
+        async with self.session.delete(api(f"/x{self.comId}/s/chat/thread/{chatId}/co-host/{userId}"), headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json(await req.json())
+
+    async def get_quizes(self, type: str = "recent", start: int = 0, size: int = 25):
+        if type == "recent":url = api(f"x{self.comId}/s/blog?type=quizzes-recent&start={start}&size={size}")
+        elif type == "trending":url = api(f"x{self.comId}/s/feed/quiz-trending?start={start}&size={size}")
+        elif type == "best":url = api(f"x{self.comId}/s/feed/quiz-best-quizzes?start={start}&size={size}")
+        else:raise TypeError("only 3 types (recent , best , trending)")
+
+        async with self.session.get(url, headers=self.headers) as req:
+            if req.status != 200:return CheckExceptions(await req.json())
+            else:return BlogList((await req.json())["blogList"]).BlogList
+
+    async def get_quiz_questions(self, quizId: str):
+        async with self.session.get(api(f"/x{self.comId}/s/blog/{quizId}?action=review"), headers=self.headers) as req:
+            if req.status != 200:return CheckExceptions(await req.json())
+            else:return QuizQuestionList((await req.json())["blog"]["quizQuestionList"]).QuizQuestionList
+
+    async def play_quiz(self, quizId: str, questions: list, answers: list, mode: int = 0):
+        data = json.dumps({
+            "mode": mode,
+            "quizAnswerList": [{
+                "optIdList": [answer],
+                "quizQuestionId": question,
+                "timeSpent": 0.0
+            } for answer, question in zip(answers, questions)],
+            "timestamp": int(timestamp() * 1000)
+        })
+        async with self.session.post(api(f"/x{self.comId}/s/blog/{quizId}/quiz/result"),headers=headers.Headers(data=data).headers, data=data) as req:
+            if req.status != 200:return CheckExceptions(await req.json())
+            else:return req.status
+
+    async def get_quiz_rankings(self, quizId: str, start: int = 0, size: int = 25):
+        async with self.session.get(api(f"/x{self.comId}/s/blog/{quizId}/quiz/result?start={start}&size={size}"),headers=self.headers) as req:
+            if req.status != 200:return CheckException(await req.json())
+            else:return QuizRankings(await req.json()).QuizRankings
+
+    async def search_user(self, username: str, start: int = 0, size: int = 25):
+        async with self.session.get(api(f"/x{self.comId}/s/user-profile?type=name&q={username}&start={start}&size={size}"),headers=self.headers) as req:
+            if req.status_code != 200: return CheckExceptions(await req.json())
+            else: return UserProfileList((await req.json())["userProfileList"]).UserProfileList
+
+    async def search_blog(self, words: str, start: int = 0, size: int = 25):
+        async with self.session.get(api(f"/x{self.comId}/s/blog?type=keywords&q={words}&start={start}&size={size}"),headers=self.headers) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            else: return BlogList((await req.json())["blogList"]).BlogList
