@@ -1,26 +1,25 @@
 import os
-import base64
 import requests
-import threading
 import ujson as json
 from uuid import UUID
-from .sockets import Wss
 from typing import BinaryIO
 from binascii import hexlify
 from time import time as timestamp
 
 from .lib import *
+from .sockets import Wss
 from .lib.objects import *
 from .lib import CheckExceptions
 
+
 class Client(Wss):
-    def __init__(self, deviceId: str = None, proxies: dict = None, Trace: bool = False):
-        self.Trace = Trace
+    def __init__(self, deviceId: str = None, proxies: dict = None, trace: bool = False):
+        self.trace = trace
         self.proxies = proxies
         self.uid = None
 
         headers.deviceId = deviceId
-        Wss.__init__(self, self, trace=self.Trace)
+        Wss.__init__(self, self, trace=self.trace)
         self.deviceId = headers.Headers().deviceId
         self.headers = headers.Headers().headers
         self.session = requests.Session()
@@ -30,21 +29,20 @@ class Client(Wss):
         self.headers = headers.Headers().headers
 
     def sid_login(self, sid: str):
-        if "sid=" not in sid:headers.sid = f"sid={sid}"
-        else:headers.sid = sid
+        if "sid=" not in sid: headers.sid = f"sid={sid}"
+        else: headers.sid = sid
+        self.headers = headers.Headers().headers
 
         req = self.session.get(api(f"/g/s/account"), headers=self.headers, proxies=self.proxies)
         info = Account(req.json()["account"])
 
         headers.uid = info.userId
         self.uid = info.userId
-        self.sid = sid
+        self.sid = headers.sid
         self.launch()
 
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
-            return info
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return info
 
     def login(self, email: str, password: str):
         data = json.dumps({
@@ -78,7 +76,7 @@ class Client(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        req = self.session.post(api("/g/s/auth/logout"), headers=headers.Headers(data=data).headers, data=data,proxies=self.proxies)
+        req = self.session.post(api("/g/s/auth/logout"), headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
         if req.status_code != 200:
             return CheckExceptions(req.json())
         else:
@@ -90,10 +88,15 @@ class Client(Wss):
             return Json(req.json())
 
     def check_device(self, deviceId: str):
+        data = json.dumps({
+            "deviceID": deviceId,
+            "timestamp": int(timestamp() * 1000),
+            "clientType": 100
+        })
         self.headers["NDCDEVICEID"] = deviceId
-        req = self.session.post(api(f"/g/s/device"), headers=self.headers)
+        req = self.session.post(api(f"/g/s/device/"), headers=headers.Headers(data=data).headers, data=data)
         if req.json()["api:statuscode"] != 0: return CheckExceptions(req.json())
-        return Json(req.json())
+        else: return f"api:message {req.json()['api:message']}\napi:statuscode {req.json()['api:statuscode']}\nThe device is fine"
 
     def upload_image(self, image: BinaryIO):
         data = image.read()
@@ -334,23 +337,29 @@ class Client(Wss):
         if req.status_code != 200: return CheckExceptions(req.json())
         return req.json()["blockedUidList"]
 
-    def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
+    def get_wall_comments(self, userId: str, sorting: str = 'newest', start: int = 0, size: int = 25):
         sorting = sorting.lower()
-
-        if sorting == "newest":
-            sorting = "newest"
-        elif sorting == "oldest":
-            sorting = "oldest"
-        elif sorting == "top":
-            sorting = "vote"
-        else:
-            raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
 
         req = self.session.get(api(f"/g/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}"),
                            headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return CommentList(req.json()["commentList"]).CommentList
 
+    def get_blog_comments(self, wikiId:str = None, blogId:str = None, quizId: str = None, sorting: str = 'newest',size: int = 25, start: int = 0):
+        sorting = sorting.lower()
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
+
+        if quizId: blogId = quizId
+        if blogId: url = api(f"/g/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}")
+        elif wikiId: url = api(f"/g/s/item/{wikiId}/comment?sort={sorting}&start={start}&size={size}")
+
+        req = self.session.get(url, headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return CommentList(req.json()["commentList"]).CommentList
+
     def send_message(self, chatId: str, message: str = None, messageType: int = 0, file: BinaryIO = None,
                      fileType: str = None, replyTo: str = None, mentionUserIds: list = None, stickerId: str = None,
                      snippetLink: str = None, ytVideo: str = None, snippetImage: BinaryIO = None, embedId: str = None,
@@ -735,24 +744,18 @@ class Client(Wss):
     def like_comment(self, commentId: str, userId: str = None, blogId: str = None):
         data = json.dumps({"value": 4, "timestamp": int(timestamp() * 1000)})
 
-        if userId:
-            url = api(f"/g/s/user-profile/{userId}/comment/{commentId}/g-vote?cv=1.2&value=1")
-        elif blogId:
-            url = api(f"/g/s/blog/{blogId}/comment/{commentId}/g-vote?cv=1.2&value=1")
-        else:
-            raise TypeError("Please put blogId or wikiId")
+        if userId: url = api(f"/g/s/user-profile/{userId}/comment/{commentId}/g-vote?cv=1.2&value=1")
+        elif blogId: url = api(f"/g/s/blog/{blogId}/comment/{commentId}/g-vote?cv=1.2&value=1")
+        else: raise TypeError("Please put blogId or wikiId")
 
         req = self.session.post(url, data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
     def unlike_comment(self, commentId: str, blogId: str = None, userId: str = None):
-        if userId:
-            url = api(f"/g/s/user-profile/{userId}/comment/{commentId}/g-vote?eventSource=UserProfileView")
-        elif blogId:
-            url = api(f"/g/s/blog/{blogId}/comment/{commentId}/g-vote?eventSource=PostDetailView")
-        else:
-            raise TypeError("Please put blog or user Id")
+        if userId: url = api(f"/g/s/user-profile/{userId}/comment/{commentId}/g-vote?eventSource=UserProfileView")
+        elif blogId: url = api(f"/g/s/blog/{blogId}/comment/{commentId}/g-vote?eventSource=PostDetailView")
+        else: raise TypeError("Please put blog or user Id")
 
         req = self.session.delete(url, headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
@@ -776,16 +779,23 @@ class Client(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        req = self.session.post(api(f"/g/s/auth/register"), data=data, headers=headers.Headers(data=data).headers,
-                            proxies=self.proxies)
+        req = self.session.post(api(f"/g/s/auth/register"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def watch_ad(self, uid: str = None):
-        data = headers.AdHeaders(uid if uid else self.uid).data
-        req = self.session.post(tapjoy, json=data, headers=headers.AdHeaders().headers, proxies=self.proxies)
-        print(req.status_code)
-        if req.status_code != 204:
-            return CheckExceptions(req.status_code)
-        else:
-            return Json(req.text)
+    def remove_host(self, chatId: str, userId: str):
+        req = self.session.delete(api(f"/g/s/chat/thread/{chatId}/co-host/{userId}"), headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+
+    def edit_comment(self, commentId: str, comment: str, userId: str):
+        data = {"content": comment, "timestamp": int(timestamp() * 1000)}
+        data = json.dumps(data)
+        req = self.session.post(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Comment(req.json()).Comments
+
+    def get_comment_info(self, commentId: str, userId: str):
+        req = self.session.get(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Comment(req.json()).Comments
