@@ -1,5 +1,4 @@
 import os
-import base64
 import requests
 import ujson as json
 from uuid import UUID
@@ -427,11 +426,11 @@ class Local:
 
     def edit_comment(self, commentId: str, comment: str, userId: str = None, blogId: str = None, wikiId: str = None,replyTo: str = None, isGuest: bool = False):
         data = {"content": comment, "timestamp": int(timestamp() * 1000)}
-        if isGuest:comType = "g-comment"
-        else:comType = "comment"
-        if userId:url = api(f"/x{self.comId}/s/user-profile/{userId}/{comType}/{commentId}")
-        elif blogId:url = api(f"/x{self.comId}/s/blog/{blogId}/{comType}/{commentId}")
-        elif wikiId:url = api(f"/x{self.comId}/s/item/{wikiId}/{comType}/{commentId}")
+        if isGuest: comType = "g-comment"
+        else: comType = "comment"
+        if userId: url = api(f"/x{self.comId}/s/user-profile/{userId}/{comType}/{commentId}")
+        elif blogId: url = api(f"/x{self.comId}/s/blog/{blogId}/{comType}/{commentId}")
+        elif wikiId: url = api(f"/x{self.comId}/s/item/{wikiId}/{comType}/{commentId}")
 
         data = json.dumps(data)
         req = self.session.post(url, data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
@@ -439,28 +438,38 @@ class Local:
         return Comment(req.json()).Comments
 
     def get_comment_info(self, commentId: str, userId: str = None, blogId: str = None, wikiId: str = None,replyTo: str = None, isGuest: bool = False):
-        if isGuest:comType = "g-comment"
-        else:comType = "comment"
-        if userId:url = api(f"/x{self.comId}/s/user-profile/{userId}/{comType}/{commentId}")
-        elif blogId:url = api(f"/x{self.comId}/s/blog/{blogId}/{comType}/{commentId}")
-        elif wikiId:url = api(f"/x{self.comId}/s/item/{wikiId}/{comType}/{commentId}")
+        if isGuest: comType = "g-comment"
+        else: comType = "comment"
+        if userId: url = api(f"/x{self.comId}/s/user-profile/{userId}/{comType}/{commentId}")
+        elif blogId: url = api(f"/x{self.comId}/s/blog/{blogId}/{comType}/{commentId}")
+        elif wikiId: url = api(f"/x{self.comId}/s/item/{wikiId}/{comType}/{commentId}")
 
         req = self.session.get(url, headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Comment(req.json()).Comments
 
-    def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
+    def get_wall_comments(self, userId: str, sorting: str = 'newest', start: int = 0, size: int = 25):
         sorting = sorting.lower()
-
-        if sorting == "newest": sorting = "newest"
-        elif sorting == "oldest": sorting = "oldest"
-        elif sorting == "top": sorting = "vote"
-        else: raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf) //// a7a wtf
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
 
         req = self.session.get(api(f"/x{self.comId}/s/user-profile/{userId}/comment?sort={sorting}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         return CommentList(req.json()["commentList"]).CommentList
 
+    def get_blog_comments(self, wikiId: str = None, blogId: str = None, quizId: str = None, sorting: str = 'newest', size: int = 25, start: int = 0):
+        sorting = sorting.lower()
+        if sorting == 'top': sorting = "vote"
+        if sorting not in ["newest", "oldest", "vote"]: raise TypeError("حط تايب يا حمار")
+
+        if quizId: blogId = quizId
+        if blogId: url = api(f"/x{self.comId}/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}")
+        elif wikiId: url = api(f"/x{self.comId}/s/item/{wikiId}/comment?sort={sorting}&start={start}&size={size}")
+
+        req = self.session.get(url, headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return CommentList(req.json()["commentList"]).CommentList
+
     def vote_comment(self, blogId: str, commentId: str, value: bool = True):
         if value: value = 1
         else: value = -1
@@ -539,8 +548,7 @@ class Local:
         else: return Json(req.json())
 
     def invite_by_host(self, chatId: str, userId: [str, list]):
-        data = json.dumps({"uidList": userId, "timestamp": int(timestamp() * 1000)})
-        req = self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/avchat-members"), headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
+        req = self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/member/{userId}/invite-av-chat"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
@@ -595,14 +603,15 @@ class Local:
         elif chatId: url = api(f"/x{self.comId}/s/chat/thread/{chatId}/admin")
         else: raise TypeError("Please put a wiki or user or chat or blog Id")
 
-        data = {"adminOpNote": {"content": note}, "adminOpName": opN, "adminOpValue": opV, "timestamp": int(timestamp() * 1000)}
-        req = self.session.post(url, headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
+        data = {"adminOpName": opN, "adminOpValue": opV, "timestamp": int(timestamp() * 1000)}
+        if note: data["adminOpNote"] = {"content": note}
+        data = json.dumps(data)
+        req = self.session.post(url=url, headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
     def unhide(self, note: str = None, blogId: str = None, userId: str = None, wikiId: str = None, chatId: str = None):
         opN, opV = 110, 0
-
         if userId:
             opN = 19
             url = api(f"/x{self.comId}/s/user-profile/{userId}/admin")
@@ -612,12 +621,12 @@ class Local:
         else: raise TypeError("Please put a wiki or user or chat or blog Id")
 
         data = {
-            "adminOpNote": {"content": note},
             "adminOpName": opN,
             "adminOpValue": opV,
             "timestamp": int(timestamp() * 1000)
         }
-
+        if note: data["adminOpNote"] = {"content": note}
+        data = json.dumps(data)
         req = self.session.post(url, headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
@@ -775,17 +784,6 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
-    def web_active_time(self):
-        try:
-            data = {"ndcId": self.comId}
-            req = self.session.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data, headers=self.web_headers)
-            try:
-                if req.json()["code"] != 200: return CheckExceptions(req.json())
-                else: Json(req.json())
-            except: return CheckExceptions(req.json())
-            return Json(req.json())
-        except: raise Exception("Unknown error")
-
     def block(self, userId: str):
         req = self.session.post(api(f"/x{self.comId}/s/block/{userId}"), headers=self.headers, proxies=self.proxies)
         if "OK" not in req.json()["api:message"]: return CheckExceptions(req.json())
@@ -801,7 +799,6 @@ class Local:
         if timers: data["userActiveTimeChunkList"] = timers
 
         data = json_minify(json.dumps(data))
-        print(self.comId)
         req = self.session.post(api(f"/x{self.comId}/s/community/stats/user-active-time"), headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
@@ -821,3 +818,52 @@ class Local:
         req = self.session.post(api(f"/x{self.comId}/s/chat/thread/{chatId}/transfer-organizer/{requestId}/accept"), headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
+
+    def remove_host(self, chatId: str, userId: str):
+        req = self.session.delete(api(f"/x{self.comId}/s/chat/thread/{chatId}/co-host/{userId}"), headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+
+    def get_quizes(self, type: str = "recent", start: int = 0, size: int = 25):
+        if type == "recent":url = api(f"x{self.comId}/s/blog?type=quizzes-recent&start={start}&size={size}")
+        elif type == "trending":url = api(f"x{self.comId}/s/feed/quiz-trending?start={start}&size={size}")
+        elif type == "best":url = api(f"x{self.comId}/s/feed/quiz-best-quizzes?start={start}&size={size}")
+        else:raise TypeError("only 3 types (recent , best , trending)")
+
+        req = self.session.get(url, headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200:return CheckExceptions(req.json())
+        else:return BlogList(req.json()["blogList"]).BlogList
+
+    def get_quiz_questions(self, quizId: str):
+        req = self.session.get(api(f"/x{self.comId}/s/blog/{quizId}?action=review"), headers=self.headers,proxies=self.proxies)
+        if req.status_code != 200:return CheckExceptions(req.json())
+        else:return QuizQuestionList(req.json()["blog"]["quizQuestionList"]).QuizQuestionList
+
+    def play_quiz(self, quizId: str, questions: list, answers: list, mode: int = 0):
+        data = json.dumps({
+            "mode": mode,
+            "quizAnswerList": [{
+                "optIdList": [answer],
+                "quizQuestionId": question,
+                "timeSpent": 0.0
+            } for answer, question in zip(answers, questions)],
+            "timestamp": int(timestamp() * 1000)
+        })
+        req = self.session.post(api(f"/x{self.comId}/s/blog/{quizId}/quiz/result"),headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
+        if req.status_code != 200:return CheckExceptions(req.json())
+        else:return req.status_code
+
+    def get_quiz_rankings(self, quizId: str, start: int = 0, size: int = 25):
+        req = self.session.get(api(f"/x{self.comId}/s/blog/{quizId}/quiz/result?start={start}&size={size}"),headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200:return CheckException(req.json())
+        else:return QuizRankings(req.json()).QuizRankings
+
+    def search_user(self, username: str, start: int = 0, size: int = 25):
+        req = self.session.get(api(f"/x{self.comId}/s/user-profile?type=name&q={username}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return UserProfileList(req.json()["userProfileList"]).UserProfileList
+
+    def search_blog(self, words: str, start: int = 0, size: int = 25):
+        req = self.session.get(api(f"/x{self.comId}/s/blog?type=keywords&q={words}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return BlogList(req.json()["blogList"]).BlogList
\ No newline at end of file
